@@ -1,10 +1,10 @@
-<?php
+<?php declare(strict_types=1);
 
 namespace Tests\Nyholm\Psr7\Integration;
 
-use Psr\Http\Message\ServerRequestInterface;
 use Http\Psr7Test\ServerRequestIntegrationTest;
 use Nyholm\Psr7\ServerRequest;
+use Psr\Http\Message\ServerRequestInterface;
 
 class ServerRequestTest extends ServerRequestIntegrationTest
 {
