@@ -1,10 +1,10 @@
-<?php
+<?php declare(strict_types=1);
 
 namespace Tests\Nyholm\Psr7\Integration;
 
-use Psr\Http\Message\StreamInterface;
 use Http\Psr7Test\StreamIntegrationTest;
 use Nyholm\Psr7\Stream;
+use Psr\Http\Message\StreamInterface;
 
 class StreamTest extends StreamIntegrationTest
 {
