@@ -1,11 +1,11 @@
-<?php
+<?php declare(strict_types=1);
 
 namespace Tests\Nyholm\Psr7\Integration;
 
-use Psr\Http\Message\UploadedFileInterface;
 use Http\Psr7Test\UploadedFileIntegrationTest;
 use Nyholm\Psr7\Factory\Psr17Factory;
 use Nyholm\Psr7\Stream;
+use Psr\Http\Message\UploadedFileInterface;
 
 class UploadedFileTest extends UploadedFileIntegrationTest
 {
